searchData={"items":[{"type":"module","title":"Proxy","doc":"`Proxy` is a Plug module that allows you to forward requests to another URL while preserving subpaths.","ref":"Proxy.html"},{"type":"module","title":"Example Usage - Proxy","doc":"defmodule MyRouter do\n      use Plug.Router\n\n      import Proxy\n\n      plug :match\n      plug :dispatch\n\n      proxy \"/path\", to: \"https://localhost:8080\"\n\n      match _ do\n        send_resp(conn, 404, \"Oops!\")\n      end\n    end\n\nThe `proxy/2` macro is used to forward requests from `/path` to `https://localhost:8080`.","ref":"Proxy.html#module-example-usage"},{"type":"function","title":"Proxy.call/2","doc":"Handles the forwarding of requests to the specified target URL. It preserves the subpaths of the original\nrequest and forwards the request to the target URL, including the request body, headers, and method.\n\nThe `Content-Type` header from the target URL response is also preserved.","ref":"Proxy.html#call/2"},{"type":"function","title":"Parameters - Proxy.call/2","doc":"- `conn`: The connection struct (`Plug.Conn`).\n  - `to`: The target URL to which requests are forwarded.","ref":"Proxy.html#call/2-parameters"},{"type":"function","title":"Example - Proxy.call/2","doc":"proxy \"/path\", to: \"https://localhost:8080\"\n\nThis forwards `/path/resource` to `https://localhost:8080/resource`.","ref":"Proxy.html#call/2-example"},{"type":"function","title":"Proxy.init/1","doc":"Initializes the `Proxy` plug with the target URL.","ref":"Proxy.html#init/1"},{"type":"function","title":"Parameters - Proxy.init/1","doc":"- `to`: The target URL to which requests will be forwarded.\n\nReturns the target URL, which is passed to the `call/2` function.","ref":"Proxy.html#init/1-parameters"},{"type":"macro","title":"Proxy.proxy/2","doc":"Defines a macro to simplify request forwarding. It forwards all requests matching the specified path\nto the given target URL, preserving subpaths.","ref":"Proxy.html#proxy/2"},{"type":"macro","title":"Parameters - Proxy.proxy/2","doc":"- `path`: The path to match and forward (e.g., `\"/path\"`).\n  - `opts`: Options, including the `:to` key, which specifies the target URL.","ref":"Proxy.html#proxy/2-parameters"},{"type":"macro","title":"Example - Proxy.proxy/2","doc":"proxy \"/api\", to: \"https://api.example.com\"\n\nThis forwards requests like `/api/resource` to `https://api.example.com/resource`.","ref":"Proxy.html#proxy/2-example"},{"type":"extras","title":"Proxy","doc":"# Proxy\n\n`Proxy` is a Plug module for Elixir that allows you to easily forward HTTP requests from one path to another URL while preserving subpaths. It simplifies the process of setting up reverse proxies in your Elixir applications.","ref":"readme.html"},{"type":"extras","title":"Features - Proxy","doc":"- Forward HTTP requests to a specified URL.\n- Preserve subpaths in forwarded requests.\n- Automatically handle and forward headers and request bodies.\n- Simple macro-based syntax for easy integration into Plug routers.","ref":"readme.html#features"},{"type":"extras","title":"Installation - Proxy","doc":"Add `proxy` to your list of dependencies in `mix.exs`:\n\n```elixir\ndefp deps do\n  [\n    {:proxy, \"~> 0.1.0\"},\n  ]\nend\n```\n\nThen run `mix deps.get` to fetch the dependencies.","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Proxy","doc":"To use the `Proxy` module, first import it into your Plug router, and then use the `proxy` macro to define the paths you want to forward.","ref":"readme.html#usage"},{"type":"extras","title":"Example - Proxy","doc":"```elixir\ndefmodule MyRouter do\n  use Plug.Router\n\n  import Proxy\n\n  plug :match\n  plug :dispatch\n\n  proxy \"/path\", to: \"https://localhost:8080\"\n\n  match _ do\n    send_resp(conn, 404, \"Oops!\")\n  end\nend\n```\n\nIn this example, any request made to `/path` (e.g., `/path/resource`) will be forwarded to `https://localhost:8080/resource`.\n\n\n#### Another Example\n\n```elixir\nproxy \"/api\", to: \"https://api.example.com\"\n```\n\nThis forwards requests like `/api/resource` to `https://api.example.com/resource`.","ref":"readme.html#example"},{"type":"extras","title":"License - Proxy","doc":"This project is licensed under the MIT License.","ref":"readme.html#license"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}